# Change Log

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.9.3

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.9.2...8d2825ef59634ac5947f40faa692bb7b6e34a373))

### Maintenance and upkeep improvements

- Update Release Scripts [#137](https://github.com/jupyterlab/pytest-check-links/pull/137) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2024-03-04&to=2024-03-12&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2024-03-04..2024-03-12&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.9.2

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.9.1...d132b588ac8fb272e1e4c8ab6d4225c9735ee41f))

### Bugs fixed

- Pin pytest 7 [#134](https://github.com/jupyterlab/pytest-check-links/pull/134) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- Fix html5lib typing [#131](https://github.com/jupyterlab/pytest-check-links/pull/131) ([@blink1073](https://github.com/blink1073))
- Fix html5lib typing [#130](https://github.com/jupyterlab/pytest-check-links/pull/130) ([@blink1073](https://github.com/blink1073))
- Bump the actions group with 1 update [#129](https://github.com/jupyterlab/pytest-check-links/pull/129) ([@dependabot](https://github.com/dependabot))
- Enforce pytest 7 [#128](https://github.com/jupyterlab/pytest-check-links/pull/128) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2024-02-18&to=2024-03-04&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2024-02-18..2024-03-04&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Adependabot+updated%3A2024-02-18..2024-03-04&type=Issues)

## 0.9.1

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.9.0...7e7f00edad437b25bd4d860651f6b6cd093a6f79))

### Bugs fixed

- Update for new version of requests-cache [#127](https://github.com/jupyterlab/pytest-check-links/pull/127) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- chore: update pre-commit hooks [#126](https://github.com/jupyterlab/pytest-check-links/pull/126) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- chore: update pre-commit hooks [#123](https://github.com/jupyterlab/pytest-check-links/pull/123) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Update ruff config [#122](https://github.com/jupyterlab/pytest-check-links/pull/122) ([@blink1073](https://github.com/blink1073))
- chore: update pre-commit hooks [#120](https://github.com/jupyterlab/pytest-check-links/pull/120) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Clean up lint handling [#119](https://github.com/jupyterlab/pytest-check-links/pull/119) ([@blink1073](https://github.com/blink1073))
- Adopt ruff format [#118](https://github.com/jupyterlab/pytest-check-links/pull/118) ([@blink1073](https://github.com/blink1073))
- chore: update pre-commit hooks [#117](https://github.com/jupyterlab/pytest-check-links/pull/117) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Ignore __main__ for coverage [#116](https://github.com/jupyterlab/pytest-check-links/pull/116) ([@blink1073](https://github.com/blink1073))
- Bump actions/checkout from 3 to 4 [#115](https://github.com/jupyterlab/pytest-check-links/pull/115) ([@dependabot](https://github.com/dependabot))
- Adopt sp-repo-review [#114](https://github.com/jupyterlab/pytest-check-links/pull/114) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2023-06-19&to=2024-02-18&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2023-06-19..2024-02-18&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Adependabot+updated%3A2023-06-19..2024-02-18&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Apre-commit-ci+updated%3A2023-06-19..2024-02-18&type=Issues)

## 0.9.0

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.8.0...8c58f8f8c42c247256f03a99504165ba7646e0e0))

### Maintenance and upkeep improvements

- Support Python 3.8-3.12 and Handle Flaky Tests [#110](https://github.com/jupyterlab/pytest-check-links/pull/110) ([@blink1073](https://github.com/blink1073))
- Update ruff [#106](https://github.com/jupyterlab/pytest-check-links/pull/106) ([@blink1073](https://github.com/blink1073))
- Use local coverage [#105](https://github.com/jupyterlab/pytest-check-links/pull/105) ([@blink1073](https://github.com/blink1073))
- Switch to pytester in tests [#103](https://github.com/jupyterlab/pytest-check-links/pull/103) ([@blink1073](https://github.com/blink1073))
- Add more linting [#100](https://github.com/jupyterlab/pytest-check-links/pull/100) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2022-12-26&to=2023-06-19&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2022-12-26..2023-06-19&type=Issues) | [@codecov](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Acodecov+updated%3A2022-12-26..2023-06-19&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Apre-commit-ci+updated%3A2022-12-26..2023-06-19&type=Issues)

## 0.8.0

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.7.1...dafddb42b22f480303a76bb46a7042e360c2379a))

### Maintenance and upkeep improvements

- Update for newer requests-cache [#98](https://github.com/jupyterlab/pytest-check-links/pull/98) ([@blink1073](https://github.com/blink1073))
- Add docstring enforcement [#97](https://github.com/jupyterlab/pytest-check-links/pull/97) ([@blink1073](https://github.com/blink1073))
- Add releaser workflows [#96](https://github.com/jupyterlab/pytest-check-links/pull/96) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2022-04-07&to=2022-12-26&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2022-04-07..2022-12-26&type=Issues) | [@bollwyvl](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Abollwyvl+updated%3A2022-04-07..2022-12-26&type=Issues) | [@codecov](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Acodecov+updated%3A2022-04-07..2022-12-26&type=Issues) | [@welcome](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Awelcome+updated%3A2022-04-07..2022-12-26&type=Issues)

## 0.7.1

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.7.0...17cf01b96afe0f933b476fd2882009db440e805d))

### Maintenance and upkeep improvements

- Include py.typed file [#48](https://github.com/jupyterlab/pytest-check-links/pull/48) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2022-04-07&to=2022-04-07&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2022-04-07..2022-04-07&type=Issues)

## 0.7.0

([Full Changelog](https://github.com/jupyterlab/pytest-check-links/compare/v0.6.0...3468259d8cd5b3becccb406bdc83c4611ade8f26))

### Enhancements made

- Update for pytest 7 [#44](https://github.com/jupyterlab/pytest-check-links/pull/44) ([@blink1073](https://github.com/blink1073))

### Maintenance and upkeep improvements

- Add flake8 and mypy linting [#46](https://github.com/jupyterlab/pytest-check-links/pull/46) ([@blink1073](https://github.com/blink1073))
- Apply Auto Formatting [#45](https://github.com/jupyterlab/pytest-check-links/pull/45) ([@blink1073](https://github.com/blink1073))
- Enforce labels on PRs [#43](https://github.com/jupyterlab/pytest-check-links/pull/43) ([@blink1073](https://github.com/blink1073))
- Update for Jupyter Releaser [#42](https://github.com/jupyterlab/pytest-check-links/pull/42) ([@blink1073](https://github.com/blink1073))

### Documentation improvements

- Add changelog entry for 0.6.0 [#41](https://github.com/jupyterlab/pytest-check-links/pull/41) ([@blink1073](https://github.com/blink1073))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab/pytest-check-links/graphs/contributors?from=2021-10-19&to=2022-04-07&type=c))

[@blink1073](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Ablink1073+updated%3A2021-10-19..2022-04-07&type=Issues) | [@codecov](https://github.com/search?q=repo%3Ajupyterlab%2Fpytest-check-links+involves%3Acodecov+updated%3A2021-10-19..2022-04-07&type=Issues)

## 0.6.0

- Handle ignore links for `ipynb` files [#39](https://github.com/jupyterlab/pytest-check-links/pull/39) ([@pratyakshajha](https://github.com/pratyakshajha))
- Drop support for Python 3.6 and add support for Python 3.10 [#40](https://github.com/jupyterlab/pytest-check-links/pull/40) ([@blink1073](https://github.com/blink1073))

## 0.5.2

- Handle attachments in notebook cells [#36](https://github.com/jupyterlab/pytest-check-links/pull/36) ([@jtpio](https://github.com/jtpio))

## 0.5.1

- Fix handling of Nested RST links [#33](https://github.com/jupyterlab/pytest-check-links/pull/33) ([@jtpio](https://github.com/jtpio))
- Fix check-links-ignore example in Readme [#32](https://github.com/jupyterlab/pytest-check-links/pull/32) ([@blink1073](https://github.com/blink1073))

## 0.5.0

- Add Ability to Ignore Link Patterns [#30](https://github.com/jupyterlab/pytest-check-links/pull/30) ([@afshin](https://github.com/afshin))
- Test with python 3.9 in CI, deal with some windows issues [#27](https://github.com/jupyterlab/pytest-check-links/pull/27) ([@bollwyvl](https://github.com/bollwyvl))

## 0.4.4

- Remove defunct Travis CI [#24](https://github.com/jupyterlab/pytest-check-links/pull/24) ([@afshin](https://github.com/afshin))

## 0.4.3

- Update for recommended usage of CheckLinks [#22](https://github.com/jupyterlab/pytest-check-links/pull/22)

## 0.4.2

- Another improvement to retry logic [#20](https://github.com/jupyterlab/pytest-check-links/pull/20)

## 0.4.1

- Clean up metadata for dist generation [#19](https://github.com/jupyterlab/pytest-check-links/pull/19)
- Improve retry logic and add python 3 classifier [#18](https://github.com/jupyterlab/pytest-check-links/pull/18)

## 0.4.0

- Drop py27 support and add badges [#15](https://github.com/jupyterlab/pytest-check-links/pull/15)
- Use requests(-cache) [#12](https://github.com/jupyterlab/pytest-check-links/pull/12)
- Add checking of self- and local html anchors [#10](https://github.com/jupyterlab/pytest-check-links/pull/10)

## 0.3.0

- Honor Retry-After Header [#9](https://github.com/jupyterlab/pytest-check-links/pull/9)
- Update metadata for JupyterLab Org [#7](https://github.com/jupyterlab/pytest-check-links/pull/7)

## 0.2.0

- Add rst handling [#4](https://github.com/jupyterlab/pytest-check-links/pull/4)
